# SimSiPM
![GCC](https://github.com/EdoPro98/SimSiPM/workflows/GCC/badge.svg?branch=master&event=push)
![AppleClang](https://github.com/EdoPro98/SimSiPM/workflows/AppleClang/badge.svg?branch=master&event=push)
![GitHub issues](https://img.shields.io/github/issues/EdoPro98/SimSiPM)
![GitHub last commit](https://img.shields.io/github/last-commit/EdoPro98/SimSiPM)
![GitHub](https://img.shields.io/github/license/EdoPro98/SimSiPM)

Library for Silicon Photomultipliers simulation. Developed for high energy physics and particle phisics simulations.

Written following the rules deescribed by FCCSW style guidelines and FCCSW C++ guidelines.

Author: Edoardo Proserpio  
Email: edoardo.proserpio@gmail.com (private)  
Email: eproserpio@studenti.uninsubria.it (instiutional)
